underscore3

Using underscore3
=================

.. code-block:: python

    import underscore3
    
    # example usage
    
    > b'result'

Changelog
=========

0.0.1: initial release (2021-10-02)

